﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Runtime.CompilerServices;
using System.Text;
using System.Threading.Tasks;
using Windows.UI.Popups;
using Gui3.Annotations;
using Gui3.common;
using Gui3.model;

namespace Gui3.viewmodel
{

    public class StudentViewModel : INotifyPropertyChanged
    {
        private static StudentViewModel _studentViewModel;
        private ObservableCollection<Student> _students;
        private Student _selectedStudent;
        private Student _newStudent;
        private int _searchId;

        public RelayCommand AddCommand { get; set; }
        public RelayCommand SaveCommand { get; set; }
        public RelayCommand DeleteCommand { get; set; }

        public ObservableCollection<Student> Students
        {
            get { return this._students; }
            set
            {
                this._students = value;
                OnPropertyChanged();
            }
        }

        public Student SelectedStudent
        {
            get { return this._selectedStudent; }
            set
            {
                this._selectedStudent = value;
                OnPropertyChanged();
            }
        }

        public Student NewStudent
        {
            get { return this._newStudent; }
            set
            {
                this._newStudent = value;
                OnPropertyChanged();
            }
        }



        public StudentViewModel()
        {
            this.Students = new ObservableCollection<Student>(Student.GetStudents());

            this.NewStudent = new Student();

            this.DeleteCommand = new RelayCommand(DeleteCommandMethod);

            this.AddCommand = new RelayCommand( AddCommandMethod);

            this.SaveCommand = new RelayCommand(SaveCommandMethod);
        }

        private void AddCommandMethod()
        {
            Students.Add(NewStudent);
            var msgDialog = new MessageDialog("New student has been created");
            msgDialog.ShowAsync();

            NewStudent = new Student();
        }

        private void DeleteCommandMethod()
        {
            if (SelectedStudent != null)
            {
                var foundStudent = Students.Where(x => x.Name == SelectedStudent.Name).FirstOrDefault();
                Students.Remove(foundStudent);

                var msgDialog = new MessageDialog("Selected student removed ");
                msgDialog.ShowAsync();
            }
            else
            {
                var msgDialog = new MessageDialog("No student selected");
                msgDialog.ShowAsync();
            }
        }

        private void SaveCommandMethod()
        {
            var msgDialog = new MessageDialog("Student info has now been saved");
            msgDialog.ShowAsync();
            SelectedStudent = new Student();
        }

        public event PropertyChangedEventHandler PropertyChanged;

        [NotifyPropertyChangedInvocator]
        protected virtual void OnPropertyChanged([CallerMemberName] string propertyName = null)
        {
            PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(propertyName));
        }
    }
}
